@@ -87,7 +87,9 @@
 #include <QShortcut>
 #include <QSplashScreen>
 #include <QStringBuilder>
+#include <QSysInfo>
 #include <QTimer>
+#include <QUrlQuery>
 #include <QVector2D>
 #include <QtGlobal>
 #include <qmath.h>
@@ -136,8 +138,6 @@ DkNoMacs::DkNoMacs(QWidget *parent, Qt::WindowFlags flags)
     am.createMenus(mMenu);
     am.enableImageActions(false);
 
-    mSaveSettings = true;
-
     mOpenDialog = 0;
     mSaveDialog = 0;
     mThumbSaver = 0;
@@ -162,7 +162,7 @@ DkNoMacs::DkNoMacs(QWidget *parent, Qt::WindowFlags flags)
     mOldGeometry = geometry();
     mOverlaid = false;
 
-    resize(850, 504);
+    resize(986, 686); // default window size, fits the settings tab
     setMinimumSize(20, 20);
 
     //// fun fact
@@ -181,7 +181,6 @@ void DkNoMacs::init()
 {
     // assign icon -> in windows the 32px version
     QString iconPath = ":/nomacs/img/nomacs.svg";
-    loadStyleSheet();
 
     QIcon nmcIcon = QIcon(iconPath);
     setObjectName("DkNoMacs");
@@ -204,7 +203,7 @@ void DkNoMacs::init()
     readSettings();
     installEventFilter(this);
 
-    if (DkSettingsManager::param().app().appMode != DkSettings::mode_frameless) {
+    if (DkSettings::normalMode(DkSettingsManager::param().app().appMode) != DkSettings::mode_frameless) {
         DkToolBarManager::inst().showDefaultToolBar(DkSettingsManager::param().app().showToolBar);
         showMenuBar(DkSettingsManager::param().app().showMenuBar);
         DkStatusBarManager::instance().show(DkSettingsManager::param().app().showStatusBar);
@@ -212,6 +211,9 @@ void DkNoMacs::init()
 
     // connections to the image loader
     connect(getTabWidget(), &DkCentralWidget::imageUpdatedSignal, this, QOverload<QSharedPointer<DkImageContainerT>>::of(&DkNoMacs::setWindowTitle));
+    connect(getTabWidget(), &DkCentralWidget::thumbViewLoadedSignal, this, [this](const QString &path) {
+        setWindowTitle(path);
+    });
 
     DkActionManager::instance().enableMovieActions(false);
 
@@ -234,12 +236,6 @@ void DkNoMacs::createStatusBar()
     setStatusBar(DkStatusBarManager::instance().statusbar());
 }
 
-void DkNoMacs::loadStyleSheet()
-{
-    DkThemeManager tm;
-    tm.applyTheme();
-}
-
 void DkNoMacs::createMenu()
 {
     setMenuBar(mMenu);
@@ -277,7 +273,7 @@ void DkNoMacs::createActions()
     connect(am.action(DkActionManager::menu_file_quick_launch), &QAction::triggered, this, &DkNoMacs::openQuickLaunch);
     connect(am.action(DkActionManager::menu_file_open_list), &QAction::triggered, this, &DkNoMacs::openFileList);
     connect(am.action(DkActionManager::menu_file_save_list), &QAction::triggered, this, &DkNoMacs::saveFileList);
-    connect(am.action(DkActionManager::menu_file_rename), &QAction::triggered, this, &DkNoMacs::renameFile);
+    connect(am.action(DkActionManager::menu_file_rename), &QAction::triggered, getTabWidget(), &DkCentralWidget::renameFile);
     connect(am.action(DkActionManager::menu_file_goto), &QAction::triggered, this, &DkNoMacs::goTo);
 
     connect(am.action(DkActionManager::menu_file_show_recent), &QAction::triggered, getTabWidget(), &DkCentralWidget::showRecentFiles);
@@ -398,33 +394,42 @@ void DkNoMacs::closeEvent(QCloseEvent *event)
     }
 
     emit closeSignal();
-    qDebug() << "saving window settings...";
     setVisible(false);
-    // showNormal();
 
-    if (mSaveSettings) {
-        DefaultSettings settings;
-        settings.setValue("geometryNomacs", geometry());
-        settings.setValue("geometry", saveGeometry());
-        settings.setValue("windowState", saveState());
+    DefaultSettings settings;
 
-        if (mExplorer)
-            settings.setValue(mExplorer->objectName(), QMainWindow::dockWidgetArea(mExplorer));
-        if (mMetaDataDock)
-            settings.setValue(mMetaDataDock->objectName(), QMainWindow::dockWidgetArea(mMetaDataDock));
-        if (mEditDock)
-            settings.setValue(mEditDock->objectName(), QMainWindow::dockWidgetArea(mEditDock));
-        if (mThumbsDock)
-            settings.setValue(mThumbsDock->objectName(), QMainWindow::dockWidgetArea(mThumbsDock));
+    // TODO: this is temporary until currentAppMode is replaced with appMode
+    if (isFullScreen())
+        DkSettingsManager::param().app().appMode = DkSettings::fullscreenMode(DkSettingsManager::param().app().appMode);
 
-        nmc::DkSettingsManager::param().save();
+    if (objectName() != "DkNoMacsFrameless") {
+        // the frameless geometry is always the screen rect, don't save
+        // NOTE: saveGeometry() does not play well with mode switching, don't use it
+        settings.setValue("windowGeometry", normalGeometry());
+        settings.setValue("windowMaximized", isMaximized());
+        qInfo() << "save geometry:" << normalGeometry() << "windowState:" << windowState();
     }
 
+    settings.setValue("windowState", saveState());
+
+    if (mExplorer)
+        settings.setValue(mExplorer->objectName(), QMainWindow::dockWidgetArea(mExplorer));
+    if (mMetaDataDock)
+        settings.setValue(mMetaDataDock->objectName(), QMainWindow::dockWidgetArea(mMetaDataDock));
+    if (mEditDock)
+        settings.setValue(mEditDock->objectName(), QMainWindow::dockWidgetArea(mEditDock));
+    if (mThumbsDock)
+        settings.setValue(mThumbsDock->objectName(), QMainWindow::dockWidgetArea(mThumbsDock));
+
+    nmc::DkSettingsManager::param().save();
+
     QMainWindow::closeEvent(event);
 }
 
 void DkNoMacs::resizeEvent(QResizeEvent *event)
 {
+    qDebug() << "resize event" << event->size();
+
     QMainWindow::resizeEvent(event);
 
     if (!mOverlaid)
@@ -550,21 +555,48 @@ void DkNoMacs::readSettings()
 {
     DefaultSettings settings;
 
-#ifdef Q_WS_WIN
-    // fixes #392 - starting maximized on 2nd screen - tested on win8 only
-    QRect r = settings.value("geometryNomacs", QRect()).toRect();
+    QRect defaultGeometry = geometry(); // from DkNoMacs()
+    defaultGeometry.moveCenter(qApp->primaryScreen()->availableGeometry().center());
 
-    if (r.width() && r.height()) // do not set the geometry if nomacs is loaded the first time
-        setGeometry(r);
-#endif
+    // we don't use restoreGeometry() because it messes up mode switching,
+    // the downside is we have to correct bad geometry ourselves
+    QRect normalGeometry = settings.value("windowGeometry", defaultGeometry).toRect();
+
+    bool recenter = false;
+
+    const QScreen *screen = qApp->screenAt(normalGeometry.topLeft());
+    if (!screen) {
+        screen = qApp->primaryScreen();
+        recenter = true;
+    }
+
+    const QRect screenRect = screen->availableGeometry();
+
+    if (!screenRect.contains(normalGeometry, true)) { // must fit completely
+        recenter = true;
+        QSize size = normalGeometry.size();
+        size.setHeight(qBound(minimumSize().height(), size.height(), screenRect.size().height()));
+        size.setWidth(qBound(minimumSize().width(), size.width(), screenRect.size().width()));
+        normalGeometry.setSize(size);
+    }
+
+    if (recenter)
+        normalGeometry.moveCenter(screenRect.center());
+
+    setGeometry(normalGeometry);
+
+    bool wasMaximized = settings.value("windowMaximized", false).toBool();
+    if (wasMaximized)
+        setWindowState(Qt::WindowMaximized);
+
+    qInfo() << "restore geometry:" << geometry() << "windowState:" << windowState();
 
-    restoreGeometry(settings.value("geometry").toByteArray());
     restoreState(settings.value("windowState").toByteArray());
 
     // restore state makes the toolbar visible - so hide it again...
     if (DkSettingsManager::param().app().appMode == DkSettings::mode_frameless) {
-        DkToolBarManager::inst().showDefaultToolBar(false);
-        DkStatusBarManager::instance().show(false);
+        DkToolBarManager::inst().showDefaultToolBar(false, false);
+        DkStatusBarManager::instance().show(false, false);
     }
 }
 
@@ -578,44 +610,61 @@ void DkNoMacs::toggleFullScreen()
 
 void DkNoMacs::enterFullScreen()
 {
-    DkSettingsManager::param().app().currentAppMode += qFloor(DkSettings::mode_end * 0.5f);
-    if (DkSettingsManager::param().app().currentAppMode < 0) {
-        qDebug() << "illegal state: " << DkSettingsManager::param().app().currentAppMode;
-        DkSettingsManager::param().app().currentAppMode = DkSettings::mode_default;
-    }
+    int appMode = DkSettingsManager::param().app().currentAppMode;
+    appMode = DkSettings::fullscreenMode(appMode);
+    DkSettingsManager::param().app().currentAppMode = appMode;
 
     menuBar()->hide();
     DkToolBarManager::inst().show(false);
     DkStatusBarManager::instance().statusbar()->hide();
     getTabWidget()->showTabs(false);
-
     restoreDocks();
 
-    // here is an issue with windows that I can't quite fix:
-    // if we send nomacs to fullscreen from an attached window (i.e. split window)
-    setWindowState(windowState() ^ Qt::WindowFullScreen);
+    qInfo() << "before enter fullscreen appMode:" << appMode << "geometry:" << geometry() << "normalGeometry:" << normalGeometry()
+            << "windowState:" << windowState();
+
+    mWasMaximized = isMaximized();
+    showFullScreen();
+
+    qInfo() << "after enter fullscreen appMode:" << appMode << "geometry:" << geometry() << "normalGeometry:" << normalGeometry()
+            << "windowState:" << windowState();
 
     if (getTabWidget()->getViewPort())
         getTabWidget()->getViewPort()->setFullScreen(true);
+
+    update();
 }
 
 void DkNoMacs::exitFullScreen()
 {
     if (isFullScreen()) {
-        DkSettingsManager::param().app().currentAppMode -= qFloor(DkSettings::mode_end * 0.5f);
-        if (DkSettingsManager::param().app().currentAppMode < 0) {
-            qDebug() << "illegal state: " << DkSettingsManager::param().app().currentAppMode;
-            DkSettingsManager::param().app().currentAppMode = DkSettings::mode_default;
-        }
+        int appMode = DkSettingsManager::param().app().currentAppMode;
+        if (!DkSettings::modeIsFullscreen(appMode))
+            qWarning() << "expected fullscreen app mode, but got" << appMode;
 
-        if (DkSettingsManager::param().app().showMenuBar)
-            mMenu->show();
-        if (DkSettingsManager::param().app().showStatusBar)
-            DkStatusBarManager::instance().statusbar()->show();
+        appMode = DkSettings::normalMode(appMode);
+        DkSettingsManager::param().app().currentAppMode = appMode;
+
+        if (appMode != DkSettings::mode_frameless) {
+            if (DkSettingsManager::param().app().showMenuBar)
+                mMenu->show();
+            if (DkSettingsManager::param().app().showStatusBar)
+                DkStatusBarManager::instance().statusbar()->show();
+        }
 
         DkToolBarManager::inst().restore();
         restoreDocks();
-        setWindowState(windowState() ^ Qt::WindowFullScreen);
+
+        qInfo() << "before exit fullscreen appMode:" << appMode << "geometry:" << geometry() << "normalGeometry:" << normalGeometry()
+                << "windowState:" << windowState();
+
+        if (mWasMaximized)
+            showMaximized();
+        else
+            showNormal();
+
+        qInfo() << "after exit fullscreen appMode:" << appMode << "geometry:" << geometry() << "normalGeometry:" << normalGeometry()
+                << "windowState:" << windowState();
 
         if (getTabWidget())
             getTabWidget()->showTabs(true);
@@ -665,6 +714,12 @@ void DkNoMacs::restartFrameless(bool)
         args << "-m"
              << "default";
 
+    if (isFullScreen())
+        args << "-f";
+
+    if (DkSettingsManager::param().app().privateMode)
+        args << "-p";
+
     if (getTabWidget()->getCurrentImage())
         args.append(getTabWidget()->getCurrentImage()->filePath());
 
@@ -821,7 +876,7 @@ void DkNoMacs::lockWindow(bool lock)
 
     qDebug() << "locking: " << lock;
 
-    if (lock) {
+    if (lock && windowOpacity() < 1.0f) {
         // setAttribute(Qt::WA_TransparentForMouseEvents);
         HWND hwnd = (HWND)winId(); // get handle of the widget
         LONG styles = GetWindowLong(hwnd, GWL_EXSTYLE);
@@ -936,6 +991,7 @@ void DkNoMacs::showExplorer(bool show, bool saveSettings)
         });
         connect(mExplorer, &DkExplorer::openDir, getTabWidget(), &DkCentralWidget::loadDirToTab);
         connect(getTabWidget(), &DkCentralWidget::imageUpdatedSignal, mExplorer, &DkExplorer::setCurrentImage);
+        connect(getTabWidget(), &DkCentralWidget::thumbViewLoadedSignal, mExplorer, &DkExplorer::setCurrentPath);
     }
 
     mExplorer->setVisible(show, saveSettings);
@@ -962,6 +1018,9 @@ void DkNoMacs::showMetaDataDock(bool show, bool saveSettings)
         addDockWidget(mMetaDataDock->getDockLocationSettings(Qt::RightDockWidgetArea), mMetaDataDock);
 
         connect(getTabWidget(), &DkCentralWidget::imageUpdatedSignal, mMetaDataDock, &DkMetaDataDock::setImage);
+        connect(getTabWidget(), &DkCentralWidget::thumbViewLoadedSignal, mMetaDataDock, [this]() {
+            mMetaDataDock->setImage(nullptr);
+        });
     }
 
     mMetaDataDock->setVisible(show, saveSettings);
@@ -1261,77 +1320,6 @@ void DkNoMacs::loadFile(const QString &filePath)
         getTabWidget()->loadFile(filePath, false);
 }
 
-// TODO: move this
-void DkNoMacs::renameFile()
-{
-    // TODO:ref move!
-    QString filePath = getTabWidget()->getCurrentFilePath();
-    QFileInfo file(filePath);
-
-    if (!file.absoluteDir().exists()) {
-        getTabWidget()->setInfo(tr("Sorry, the directory: %1 does not exist\n").arg(file.absolutePath()));
-        return;
-    }
-    if (file.exists() && !file.isWritable()) {
-        getTabWidget()->setInfo(tr("Sorry, I can't write to the fileInfo: %1").arg(file.fileName()));
-        return;
-    }
-
-    QString fileName = file.fileName();
-    int dotIdx = fileName.lastIndexOf(".");
-    QString baseName = dotIdx != -1 ? fileName.left(dotIdx) : fileName;
-
-    bool ok = false;
-    QString newFileName = QInputDialog::getText(this, baseName, tr("Rename:"), QLineEdit::Normal, baseName, &ok);
-
-    if (ok && !newFileName.isEmpty() && newFileName != baseName) {
-        if (!file.suffix().isEmpty())
-            newFileName.append("." + file.suffix());
-
-        qDebug() << "renaming: " << file.fileName() << " -> " << newFileName;
-        QFileInfo renamedFile = QFileInfo(file.absoluteDir(), newFileName);
-
-        // overwrite file?
-        // the second comparison is important for windows (case insensitive filenames)
-        if (renamedFile.exists() && renamedFile.absoluteFilePath().compare(file.absoluteFilePath(), Qt::CaseInsensitive) != 0) {
-            QMessageBox infoDialog(this);
-            infoDialog.setWindowTitle(tr("Question"));
-            infoDialog.setText(tr("The fileInfo: %1  already exists.\n Do you want to replace it?").arg(newFileName));
-            infoDialog.setIcon(QMessageBox::Question);
-            infoDialog.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
-            infoDialog.setDefaultButton(QMessageBox::No);
-            infoDialog.show();
-            int choice = infoDialog.exec();
-
-            if (choice == QMessageBox::Yes) {
-                QFile oldFile(renamedFile.absoluteFilePath());
-                bool removed = oldFile.remove();
-
-                // tell user that deleting went wrong, and stop the renaming
-                if (!removed) {
-                    getTabWidget()->setInfo(tr("Sorry, I can't delete: %1").arg(file.fileName()));
-                    return;
-                }
-            } else
-                return; // cancel renaming
-        }
-
-        if (getTabWidget()->getViewPort())
-            getTabWidget()->getViewPort()->unloadImage();
-
-        QFile newFile(file.absoluteFilePath());
-        bool renamed = newFile.rename(renamedFile.absoluteFilePath());
-
-        // tell user that deleting went wrong, and stop the renaming
-        if (!renamed)
-            getTabWidget()->setInfo(tr("Sorry, I can't rename: %1").arg(file.fileName()));
-        else if (DkSettingsManager::param().resources().loadSavedImage == DkSettings::ls_load)
-            getTabWidget()->loadFile(renamedFile.absoluteFilePath());
-        else if (getTabWidget()->getViewPort())
-            getTabWidget()->getViewPort()->loadNextFileFast();
-    }
-}
-
 void DkNoMacs::find(bool filterAction)
 {
     if (!getTabWidget()->getCurrentImageLoader())
@@ -1340,7 +1328,6 @@ void DkNoMacs::find(bool filterAction)
     if (filterAction) {
         int db = (QObject::sender() == DkActionManager::instance().action(DkActionManager::menu_tools_filter)) ? DkSearchDialog::filter_button
                                                                                                                : DkSearchDialog::find_button;
-
         qDebug() << "default button: " << db;
         DkSearchDialog *searchDialog = new DkSearchDialog(this);
         searchDialog->setDefaultButton(db);
@@ -1473,9 +1460,8 @@ void DkNoMacs::computeThumbsBatch()
 
 void DkNoMacs::aboutDialog()
 {
-    DkSplashScreen *spScreen = new DkSplashScreen(this);
-    spScreen->exec();
-    spScreen->deleteLater();
+    DkSplashScreen splash;
+    splash.exec();
 }
 
 void DkNoMacs::openDocumentation()
@@ -1486,8 +1472,31 @@ void DkNoMacs::openDocumentation()
 
 void DkNoMacs::bugReport()
 {
-    QString url = "https://github.com/nomacs/nomacs/issues/new";
-    QDesktopServices::openUrl(QUrl(url));
+    QString info = R"(
+**Description**
+A clear and concise description.
+
+**Steps to Reproduce**
+List the sequence of actions leading to the bug.
+
+**Expected Behavior**
+A clear and concise description of what you expected to happen.
+
+**Screenshot / Screencast / Images**
+Add screen recording or example files to help illustrate the problem.
+
+**Additional context**
+Add any other context about the problem.
+
+**System Info**)";
+    info += '\n' + DkUtils::getBuildInfo().replace("\n\n", "");
+
+    QUrlQuery query;
+    query.addQueryItem("body", info);
+    QUrl url("https://github.com/nomacs/nomacs/issues/new");
+    url.setQuery(query);
+
+    QDesktopServices::openUrl(url);
 }
 
 void DkNoMacs::cleanSettings()
@@ -1515,6 +1524,9 @@ void DkNoMacs::newInstance(const QString &filePath)
     else
         args.append(filePath);
 
+    DkSettingsManager::param().app().appMode = DkSettingsManager::param().app().currentAppMode;
+    DkSettingsManager::param().save();
+
     QProcess::startDetached(exe, args);
 }
 
@@ -1554,6 +1566,13 @@ void DkNoMacs::restartWithPseudoColor(bool contrast)
     else
         args << "-m"
              << "default";
+
+    if (isFullScreen())
+        args << "-f";
+
+    if (DkSettingsManager::param().app().privateMode)
+        args << "-p";
+
     args.append(getTabWidget()->getCurrentFilePath());
 
     bool started = mProcess.startDetached(exe, args);
@@ -1747,21 +1766,27 @@ void DkNoMacs::setWindowTitle(const QString &filePath, const QSize &size, bool e
     // TODO: move!
     DkStatusBar *bar = DkStatusBarManager::instance().statusbar();
 
-    if (((vp && !vp->getController()->getFileInfoLabel()->isVisible())
-         || !DkSettingsManager::param().slideShow().display.testBit(DkSettings::display_creation_date))
-        && getTabWidget()->getCurrentImage()) {
-        // create statusbar info
-        QSharedPointer<DkMetaDataT> metaData = getTabWidget()->getCurrentImage()->getMetaData();
-        QString dateString = metaData->getExifValue("DateTimeOriginal");
-        dateString = DkUtils::convertDateString(dateString, fInfo);
-        bar->setMessage(dateString, DkStatusBar::status_time_info);
-    } else
+    if (fInfo.isDir()) {
         bar->setMessage("", DkStatusBar::status_time_info); // hide label
-
-    if (fInfo.exists())
-        bar->setMessage(DkUtils::readableByte((float)fInfo.size()), DkStatusBar::status_filesize_info);
-    else
         bar->setMessage("", DkStatusBar::status_filesize_info);
+        bar->setMessage("", DkStatusBar::status_filenumber_info);
+    } else {
+        if (((vp && !vp->getController()->getFileInfoLabel()->isVisible())
+             || !DkSettingsManager::param().slideShow().display.testBit(DkSettings::display_creation_date))
+            && getTabWidget()->getCurrentImage()) {
+            // create statusbar info
+            QSharedPointer<DkMetaDataT> metaData = getTabWidget()->getCurrentImage()->getMetaData();
+            QString dateString = metaData->getExifValue("DateTimeOriginal");
+            dateString = DkUtils::convertDateString(dateString, fInfo);
+            bar->setMessage(dateString, DkStatusBar::status_time_info);
+        } else
+            bar->setMessage("", DkStatusBar::status_time_info); // hide label
+
+        if (fInfo.exists())
+            bar->setMessage(DkUtils::readableByte(fInfo.size()), DkStatusBar::status_filesize_info);
+        else
+            bar->setMessage("", DkStatusBar::status_filesize_info);
+    }
 }
 
 void DkNoMacs::settingsChanged()
@@ -2029,6 +2054,8 @@ void DkNoMacsSync::dropEvent(QDropEvent *event)
 DkNoMacsIpl::DkNoMacsIpl(QWidget *parent, Qt::WindowFlags flags)
     : DkNoMacsSync(parent, flags)
 {
+    DkSettingsManager::param().app().appMode = DkSettings::mode_default;
+
     // init members
     DkCentralWidget *cw = new DkCentralWidget(this);
     setCentralWidget(cw);
@@ -2036,9 +2063,6 @@ DkNoMacsIpl::DkNoMacsIpl(QWidget *parent, Qt::WindowFlags flags)
     init();
     setAcceptDrops(true);
     setMouseTracking(true); // receive mouse event everytime
-
-    DkSettingsManager::param().app().appMode = 0;
-    DkSettingsManager::param().app().appMode = DkSettings::mode_default;
 }
 
 // FramelessNoMacs --------------------------------------------------------------------
@@ -2074,20 +2098,13 @@ DkNoMacsFrameless::DkNoMacsFrameless(QWidget *parent, Qt::WindowFlags flags)
     am.action(DkActionManager::menu_view_frameless)->setChecked(true);
     am.action(DkActionManager::menu_view_frameless)->blockSignals(false);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    mDesktop = QApplication::desktop();
-
     chooseMonitor(false);
-#endif
-    show();
+    connect(am.action(DkActionManager::menu_view_monitors), &QAction::triggered, this, [this] {
+        chooseMonitor(true);
+    });
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(mDesktop, &QDesktopWidget::workAreaResized, this, &DkNoMacsFrameless::chooseMonitor);
-    connect(am.action(DkActionManager::menu_view_monitors), &QAction::triggered, this, &DkNoMacsFrameless::chooseMonitor);
-#endif
-
-    setObjectName("DkNoMacsFrameless");
-    DkStatusBarManager::instance().show(false); // fix
+    setObjectName("DkNoMacsFrameless"); // init() changed it
+    DkStatusBarManager::instance().show(false, false);
 
     // actions that should always be disabled
     DkActionManager::instance().action(DkActionManager::menu_view_fit_frame)->setEnabled(false);
@@ -2103,19 +2120,37 @@ void DkNoMacsFrameless::createContextMenu()
 
     DkActionManager &am = DkActionManager::instance();
     am.contextMenu()->addSeparator();
+    am.contextMenu()->addAction(am.action(DkActionManager::menu_view_monitors));
     am.contextMenu()->addAction(am.action(DkActionManager::menu_file_exit));
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+void DkNoMacsFrameless::paintEvent(QPaintEvent *event)
+{
+    // paint everything except the central/transparent area
+    const QRegion mask = QRegion(event->rect()).subtracted(centralWidget()->geometry());
+
+    if (!mask.isEmpty()) {
+        QPainter painter(this);
+        const QColor &bgColor = DkSettingsManager::param().display().bgColor;
+        for (auto it = mask.begin(); it != mask.end(); ++it)
+            painter.fillRect(*it, bgColor);
+    }
+
+    DkNoMacs::paintEvent(event);
+}
+
 void DkNoMacsFrameless::chooseMonitor(bool force)
 {
-    if (!mDesktop)
+    QScreen *oldScreen = qApp->screenAt(geometry().topLeft());
+    if (!oldScreen) {
+        qWarning() << "[chooseMonitor] invalid geometry";
         return;
+    }
 
-    QRect screenRect = mDesktop->availableGeometry();
+    disconnect(oldScreen, nullptr, this, nullptr);
+    QRect screenRect = oldScreen->availableGeometry();
 
-    // ask the user which monitor to use
-    if (mDesktop->screenCount() > 1) {
+    if (qApp->screens().count() > 1) {
         DkChooseMonitorDialog *cmd = new DkChooseMonitorDialog(this);
         cmd->setWindowTitle(tr("Choose a Monitor"));
 
@@ -2130,8 +2165,20 @@ void DkNoMacsFrameless::chooseMonitor(bool force)
     }
 
     setGeometry(screenRect);
+
+    QScreen *newScreen = qApp->screenAt(geometry().topLeft());
+    if (!newScreen) {
+        qWarning() << "[chooseMonitor] invalid screenRect returned";
+        return;
+    }
+
+    connect(newScreen, &QScreen::availableGeometryChanged, this, [this](const QRect &rect) {
+        qInfo() << "[chooseMonitor] screen geometry changed" << rect;
+        chooseMonitor(true);
+    });
+
+    qInfo() << "[chooseMonitor] force:" << force << "set geometry:" << geometry() << "windowState:" << windowState();
 }
-#endif
 
 // >DIR diem: eating shortcut overrides
 bool DkNoMacsFrameless::eventFilter(QObject *, QEvent *event)
@@ -2155,23 +2202,13 @@ bool DkNoMacsFrameless::eventFilter(QObject *, QEvent *event)
     return false;
 }
 
-void DkNoMacsFrameless::closeEvent(QCloseEvent *event)
-{
-    // do not save the window size
-    if (mSaveSettings)
-        DkSettingsManager::param().save();
-
-    mSaveSettings = false;
-
-    DkNoMacs::closeEvent(event);
-}
-
 // Transfer function:
 
 DkNoMacsContrast::DkNoMacsContrast(QWidget *parent, Qt::WindowFlags flags)
     : DkNoMacsSync(parent, flags)
 {
     setObjectName("DkNoMacsContrast");
+    DkSettingsManager::param().app().appMode = DkSettings::mode_contrast;
 
     // init members
     DkCentralWidget *cw = new DkCentralWidget(this);
@@ -2184,12 +2221,6 @@ DkNoMacsContrast::DkNoMacsContrast(QWidget *parent, Qt::WindowFlags flags)
     setAcceptDrops(true);
     setMouseTracking(true); // receive mouse event everytime
 
-    DkSettingsManager::param().app().appMode = DkSettings::mode_contrast;
-    setObjectName("DkNoMacsContrast");
-
-    // show it...
-    show();
-
     // TODO: this should be checked but no event should be called
     DkActionManager &am = DkActionManager::instance();
     am.action(DkActionManager::menu_panel_transfertoolbar)->blockSignals(true);
